#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
#
# Content: wato plugin for snmp check 'checkpoint_apcl'
#          to configure waring/critical levels for last update
#
# 2022-11-30: fixed CheckParameterRulespecWithoutItem (from CheckParameterRulespecWithItem)
# 2023-05-29: moved wato file to ~/local/lib/check_mk/gui/plugins/wato
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
    DropdownChoice,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_apcl():
    return Dictionary(
        elements=[
            ('levels_no_update',
             Tuple(
                 title=_('Maximum days no update'),
                 elements=[
                     Integer(
                         title=_('Warning at'),
                         unit='days',
                         default_value=7,
                         minvalue=1,
                         help=_('Warning if version older then days')),
                     Integer(
                         title=_('Critical at'),
                         unit='days',
                         default_value=14,
                         minvalue=1,
                         help=_('critical if version older then days'))
                 ],
             )),
            ('timeformat',
             DropdownChoice(
                 title=_('Select time format for updeate verion string'),
                 help=
                 _('Check Point is changing the format of the version string from time to time :-(. '
                   'If this happens you can adjust the check here.'),
                 choices=[
                     ('%y%m%d', _('YYMMDD')),
                     ('%d%m%y', _('DDMMYY')),
                 ])),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='checkpoint_apcl',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_apcl,
        title=lambda: _('Check Point Application Control'),
    ))
